pub struct CloseOptions {
pub return_back: Option<bool>,
}Expand description
Options supported by crate::webapp::TelegramWebApp::close_with_options.
Examples
use telegram_webapp_sdk::webapp::{CloseOptions, TelegramWebApp};
if let Some(app) = TelegramWebApp::instance() {
let _ = app.close_with_options(&CloseOptions {
return_back: Some(true)
});
}Fields
return_back: Option<bool>If true and the host client is Bot API 7.6+, returns the user to the
previous chat instead of just closing the mini app.