BackButton

Struct BackButton 

pub struct BackButton { /* private fields */ }
Available on crate feature yew only.
Yew component for the native back button.

Shows or hides WebApp.BackButton based on the visible prop and routes clicks through the on_click callback. The subscription is removed and the button hidden on unmount.

Examples

use telegram_webapp_sdk::yew::BackButton;
use yew::prelude::*;

#[function_component(App)]
fn app() -> Html {
    let cb = Callback::from(|_| {
        web_sys::console::log_1(&"back".into());
    });
    html! { <BackButton visible={true} on_click={cb} /> }
}