BottomButton

Struct BottomButton 

pub struct BottomButton { /* private fields */ }
Available on crate feature yew only.
Yew component that configures the primary Telegram bottom button.

The button is shown when the component is mounted and hidden on drop. Text, colors and callback can be customized through BottomButtonProps.

Examples

use telegram_webapp_sdk::yew::BottomButton;
use yew::prelude::*;

#[component]
fn App() -> Html {
    let on_click = Callback::from(|_| {});
    html! { <BottomButton text="OK" color="#000" text_color="#fff" {on_click} /> }
}