Router

Struct Router 

pub struct Router { /* private fields */ }
Sequential router executing registered page handlers.

Implementations

Source

impl Router

pub fn new() -> Self

Creates an empty router.

pub fn register(self, path: &'static str, handler: fn()) -> Self

Adds a page handler associated with path and returns the updated router.

pub fn start(self)

Starts the router, invoking handlers in order of registration.