pub struct BottomButton { /* private fields */ }Available on crate feature
yew only.Expand description
Yew component that configures the primary Telegram bottom button.
The button is shown when the component is mounted and hidden on drop.
Text, colors and callback can be customized through BottomButtonProps.
Examples
use telegram_webapp_sdk::yew::BottomButton;
use yew::prelude::*;
#[component]
fn App() -> Html {
let on_click = Callback::from(|_| {});
html! { <BottomButton text="OK" color="#000" text_color="#fff" {on_click} /> }
}Trait Implementations
Sourceimpl BaseComponent for BottomButtonwhere
Self: 'static,
impl BaseComponent for BottomButtonwhere
Self: 'static,
Sourcetype Properties = BottomButtonProps
type Properties = BottomButtonProps
The Component’s Properties.
Sourcefn update(&mut self, _ctx: &Context<Self>, _msg: Self::Message) -> bool
fn update(&mut self, _ctx: &Context<Self>, _msg: Self::Message) -> bool
Updates component’s internal state.
Sourcefn changed(
&mut self,
_ctx: &Context<Self>,
_old_props: &Self::Properties,
) -> bool
fn changed( &mut self, _ctx: &Context<Self>, _old_props: &Self::Properties, ) -> bool
React to changes of component properties.
Sourcefn view(&self, ctx: &Context<Self>) -> HtmlResult
fn view(&self, ctx: &Context<Self>) -> HtmlResult
Returns a component layout to be rendered.
Sourcefn rendered(&mut self, _ctx: &Context<Self>, _first_render: bool)
fn rendered(&mut self, _ctx: &Context<Self>, _first_render: bool)
Notified after a layout is rendered.
Sourcefn prepare_state(&self) -> Option<String>
fn prepare_state(&self) -> Option<String>
Prepares the server-side state.
Sourceimpl Debug for BottomButton
impl Debug for BottomButton
Sourceimpl FunctionProvider for BottomButton
impl FunctionProvider for BottomButton
Sourcetype Properties = BottomButtonProps
type Properties = BottomButtonProps
Properties for the Function Component.
Sourcefn run(ctx: &mut HookContext, props: &Self::Properties) -> HtmlResult
fn run(ctx: &mut HookContext, props: &Self::Properties) -> HtmlResult